@@ -1,9 +1,9 @@
-/* $Id: files.c,v 1.340 2006/12/15 05:03:08 dolorous Exp $ */
+/* $Id: files.c,v 1.348 2007/01/11 23:11:46 dolorous Exp $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
  *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Chris Allegretta    *
- *   Copyright (C) 2005, 2006 David Lawrence Ramsey                       *
+ *   Copyright (C) 2005, 2006, 2007 David Lawrence Ramsey                 *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 2, or (at your option)  *
@@ -579,9 +579,9 @@ void read_file(FILE *f, const char *filename)
  * "New File" if the file is missing.  Otherwise, say "[filename] not
  * found".
  *
- * Return -2 if we say "New File".  Otherwise, -1 if the file isn't
- * opened, 0 otherwise.  The file might still have an error while
- * reading with a 0 return value.  *f is set to the opened file. */
+ * Return -2 if we say "New File", -1 if the file isn't opened, and 0
+ * otherwise.  The file might still have an error while reading with a 0
+ * return value.  *f is set to the opened file. */
 int open_file(const char *filename, bool newfie, FILE **f)
 {
     struct stat fileinfo;
@@ -681,7 +681,7 @@ void do_insertfile(
     int i;
     const char *msg;
     char *ans = mallocstrcpy(NULL, "");
-	/* The last answer the user typed on the statusbar. */
+	/* The last answer the user typed at the statusbar prompt. */
     filestruct *edittop_save = openfile->edittop;
     size_t current_x_save = openfile->current_x;
     ssize_t current_y_save = openfile->current_y;
@@ -1250,28 +1250,27 @@ int copy_file(FILE *inn, FILE *out)
     return retval;
 }
 
-/* Write a file out.  If f_open isn't NULL, we assume that it is a
- * stream associated with the file, and we don't try to open it
+/* Write a file out to disk.  If f_open isn't NULL, we assume that it is
+ * a stream associated with the file, and we don't try to open it
  * ourselves.  If tmp is TRUE, we set the umask to disallow anyone else
  * from accessing the file, we don't set the filename to its name, and
  * we don't print out how many lines we wrote on the statusbar.
  *
  * tmp means we are writing a temporary file in a secure fashion.  We
- * use it when spell checking or dumping the file on an error.
+ * use it when spell checking or dumping the file on an error.  If
+ * append is APPEND, it means we are appending instead of overwriting.
+ * If append is PREPEND, it means we are prepending instead of
+ * overwriting.  If nonamechange is TRUE, we don't change the current
+ * filename.  nonamechange is ignored if tmp is FALSE, we're appending,
+ * or we're prepending.
  *
- * append == APPEND means we are appending instead of overwriting.
- * append == PREPEND means we are prepending instead of overwriting.
- *
- * nonamechange means don't change the current filename.  It is ignored
- * if tmp is FALSE or if we're appending/prepending.
- *
- * Return 0 on success or -1 on error. */
-int write_file(const char *name, FILE *f_open, bool tmp, append_type
+ * Return TRUE on success or FALSE on error. */
+bool write_file(const char *name, FILE *f_open, bool tmp, append_type
 	append, bool nonamechange)
 {
-    int retval = -1;
+    bool retval = FALSE;
 	/* Instead of returning in this function, you should always
-	 * merely set retval and then goto cleanup_and_exit. */
+	 * set retval and then goto cleanup_and_exit. */
     size_t lineswritten = 0;
     const filestruct *fileptr = openfile->fileage;
     int fd;
@@ -1686,7 +1685,7 @@ int write_file(const char *name, FILE *f_open, bool tmp, append_type
 	titlebar(NULL);
     }
 
-    retval = 0;
+    retval = TRUE;
 
   cleanup_and_exit:
     free(realname);
@@ -1697,11 +1696,12 @@ int write_file(const char *name, FILE *f_open, bool tmp, append_type
 }
 
 #ifndef NANO_TINY
-/* Write a marked selection from a file out. */
-int write_marked_file(const char *name, FILE *f_open, bool tmp,
+/* Write a marked selection from a file out to disk.  Return TRUE on
+ * success or FALSE on error. */
+bool write_marked_file(const char *name, FILE *f_open, bool tmp,
 	append_type append)
 {
-    int retval = -1;
+    bool retval;
     bool old_modified = openfile->modified;
 	/* write_file() unsets the modified flag. */
     bool added_magicline = FALSE;
@@ -1746,16 +1746,17 @@ int write_marked_file(const char *name, FILE *f_open, bool tmp,
 /* Write the current file to disk.  If the mark is on, write the current
  * marked selection to disk.  If exiting is TRUE, write the file to disk
  * regardless of whether the mark is on, and without prompting if the
- * TEMP_FILE flag is set. */
-int do_writeout(bool exiting)
+ * TEMP_FILE flag is set.  Return TRUE on success or FALSE on error. */
+bool do_writeout(bool exiting)
 {
-    int i, retval = 0;
+    int i;
     append_type append = OVERWRITE;
     char *ans;
-	/* The last answer the user typed on the statusbar. */
+	/* The last answer the user typed at the statusbar prompt. */
 #ifdef NANO_EXTRA
     static bool did_credits = FALSE;
 #endif
+    bool retval = FALSE;
 
     currshortcut = writefile_list;
 
@@ -1764,7 +1765,7 @@ int do_writeout(bool exiting)
 		FALSE);
 
 	/* Write succeeded. */
-	if (retval == 0)
+	if (retval)
 	    return retval;
     }
 
@@ -1820,7 +1821,7 @@ int do_writeout(bool exiting)
 	 * encoded null), treat it as though it's blank. */
 	if (i < 0 || answer[0] == '\n') {
 	    statusbar(_("Cancelled"));
-	    retval = -1;
+	    retval = FALSE;
 	    break;
 	} else {
 	    ans = mallocstrcpy(ans, answer);
@@ -1874,7 +1875,7 @@ int do_writeout(bool exiting)
 		strcasecmp(answer, "zzy") == 0) {
 		do_credits();
 		did_credits = TRUE;
-		retval = -1;
+		retval = FALSE;
 		break;
 	    }
 #endif
@@ -1940,16 +1941,16 @@ int do_writeout(bool exiting)
 	    sunder(answer);
 	    align(&answer);
 
-#ifndef NANO_TINY
 	    /* Here's where we allow the selected text to be written to
 	     * a separate file.  If we're using restricted mode, this is
 	     * disabled, since it allows reading from or writing to
 	     * files not specified on the command line. */
-	    if (!ISSET(RESTRICTED) && !exiting && openfile->mark_set)
-		retval = write_marked_file(answer, NULL, FALSE, append);
-	    else
+	    retval =
+#ifndef NANO_TINY
+		(!ISSET(RESTRICTED) && !exiting && openfile->mark_set) ?
+		write_marked_file(answer, NULL, FALSE, append) :
 #endif
-		retval = write_file(answer, NULL, FALSE, append, FALSE);
+		write_file(answer, NULL, FALSE, append, FALSE);
 
 	    break;
 	}
@@ -2049,15 +2050,19 @@ void free_chararray(char **array, size_t len)
 #endif
 
 #ifndef DISABLE_TABCOMP
-/* Is the given file a directory? */
-int is_dir(const char *buf)
+/* Is the given path a directory? */
+bool is_dir(const char *buf)
 {
-    char *dirptr = real_dir_from_tilde(buf);
+    char *dirptr;
     struct stat fileinfo;
-    int retval = (stat(dirptr, &fileinfo) != -1 &&
-	S_ISDIR(fileinfo.st_mode));
+    bool retval;
 
-    assert(buf != NULL && dirptr != buf);
+    assert(buf != NULL);
+
+    dirptr = real_dir_from_tilde(buf);
+
+    retval = (stat(dirptr, &fileinfo) != -1 &&
+	S_ISDIR(fileinfo.st_mode));
 
     free(dirptr);
 
