@@ -1,9 +1,9 @@
-/* $Id: search.c,v 1.193 2006/12/13 00:27:45 dolorous Exp $ */
+/* $Id: search.c,v 1.197 2007/01/09 23:42:34 dolorous Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
  *   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 Chris Allegretta    *
- *   Copyright (C) 2005, 2006 David Lawrence Ramsey                       *
+ *   Copyright (C) 2005, 2006, 2007 David Lawrence Ramsey                 *
  *   This program is free software; you can redistribute it and/or modify *
  *   it under the terms of the GNU General Public License as published by *
  *   the Free Software Foundation; either version 2, or (at your option)  *
@@ -39,21 +39,20 @@ static bool history_changed = FALSE;
 static bool regexp_compiled = FALSE;
 	/* Have we compiled any regular expressions? */
 
-/* Regular expression helper functions. */
-
-/* Compile the given regular expression.  Return value 0 means the
- * expression was invalid, and we wrote an error message on the status
- * bar.  Return value 1 means success. */
-int regexp_init(const char *regexp)
+/* Compile the regular expression regexp to see if it's valid.  Return
+ * TRUE if it is, or FALSE otherwise. */
+bool regexp_init(const char *regexp)
 {
-    int rc = regcomp(&search_regexp, regexp, REG_EXTENDED
+    int rc;
+
+    assert(!regexp_compiled);
+
+    rc = regcomp(&search_regexp, regexp, REG_EXTENDED
 #ifndef NANO_TINY
 	| (ISSET(CASE_SENSITIVE) ? 0 : REG_ICASE)
 #endif
 	);
 
-    assert(!regexp_compiled);
-
     if (rc != 0) {
 	size_t len = regerror(rc, &search_regexp, NULL, 0);
 	char *str = charalloc(len);
@@ -61,11 +60,13 @@ int regexp_init(const char *regexp)
 	regerror(rc, &search_regexp, str, len);
 	statusbar(_("Bad regex \"%s\": %s"), regexp, str);
 	free(str);
-	return 0;
+
+	return FALSE;
     }
 
     regexp_compiled = TRUE;
-    return 1;
+
+    return TRUE;
 }
 
 /* Decompile the compiled regular expression we used in the last
@@ -218,9 +219,8 @@ int search_init(bool replacing, bool use_answer)
 #ifdef HAVE_REGEX_H
 		/* Use last_search if answer is an empty string, or
 		 * answer if it isn't. */
-		if (ISSET(USE_REGEXP) &&
-			regexp_init((i == -2) ? last_search :
-			answer) == 0)
+		if (ISSET(USE_REGEXP) && !regexp_init((i == -2) ?
+			last_search : answer))
 		    return -1;
 #endif
 		break;
@@ -511,7 +511,7 @@ void do_research(void)
     if (last_search[0] != '\0') {
 #ifdef HAVE_REGEX_H
 	/* Since answer is "", use last_search! */
-	if (ISSET(USE_REGEXP) && regexp_init(last_search) == 0)
+	if (ISSET(USE_REGEXP) && !regexp_init(last_search))
 	    return;
 #endif
 
@@ -977,7 +977,7 @@ void do_gotolinecolumn(ssize_t line, ssize_t column, bool use_answer,
     if (interactive) {
 	char *ans = mallocstrcpy(NULL, answer);
 
-	/* Ask for it. */
+	/* Ask for the line and column. */
 	int i = do_prompt(FALSE,
 #ifndef DISABLE_TABCOMP
 		TRUE,
